# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`globus`](#globus): Manage Globus
* [`globus::cli`](#globus--cli): Manage Globus CLI
* [`globus::sdk`](#globus--sdk): Manage Globus SDK
* [`globus::timer`](#globus--timer): Manage Globus Timer

#### Private Classes

* `globus::config`: Manage globus configs
* `globus::install`: manage Globus install
* `globus::python`: Manage Globus Python dependency
* `globus::repo::deb`: Manage globus repo
* `globus::repo::el`: Manage globus repo
* `globus::service`: Manage Globus service
* `globus::user`: Manage globus user and group

### Functions

* [`globus::endpoint_setup_args`](#globus--endpoint_setup_args)
* [`globus::node_setup_args`](#globus--node_setup_args)

## Classes

### <a name="globus"></a>`globus`

Manage Globus

#### Examples

##### Install and setup a Globus v5.4 endpoint

```puppet
class { 'globus':
  display_name  => 'REPLACE My Site Globus',
  owner         => 'REPLACE-user@example.com',
}
```

#### Parameters

The following parameters are available in the `globus` class:

* [`release_url`](#-globus--release_url)
* [`gcs_repo_baseurl`](#-globus--gcs_repo_baseurl)
* [`gcs_repo_testing_baseurl`](#-globus--gcs_repo_testing_baseurl)
* [`enable_testing_repos`](#-globus--enable_testing_repos)
* [`extra_gridftp_settings`](#-globus--extra_gridftp_settings)
* [`manage_service`](#-globus--manage_service)
* [`run_setup_commands`](#-globus--run_setup_commands)
* [`manage_firewall`](#-globus--manage_firewall)
* [`manage_epel`](#-globus--manage_epel)
* [`manage_user`](#-globus--manage_user)
* [`group_gid`](#-globus--group_gid)
* [`user_uid`](#-globus--user_uid)
* [`package_name`](#-globus--package_name)
* [`display_name`](#-globus--display_name)
* [`project_id`](#-globus--project_id)
* [`project_admin`](#-globus--project_admin)
* [`owner`](#-globus--owner)
* [`organization`](#-globus--organization)
* [`deployment_key`](#-globus--deployment_key)
* [`keywords`](#-globus--keywords)
* [`department`](#-globus--department)
* [`contact_email`](#-globus--contact_email)
* [`contact_info`](#-globus--contact_info)
* [`info_link`](#-globus--info_link)
* [`description`](#-globus--description)
* [`public`](#-globus--public)
* [`incoming_port_range`](#-globus--incoming_port_range)
* [`outgoing_port_range`](#-globus--outgoing_port_range)
* [`ip_address`](#-globus--ip_address)
* [`export_node`](#-globus--export_node)
* [`import_node`](#-globus--import_node)

##### <a name="-globus--release_url"></a>`release_url`

Data type: `Variant[Stdlib::Httpsurl, Stdlib::Httpurl]`

Release URL of Globus release RPM

Default value: `'https://downloads.globus.org/toolkit/globus-connect-server/globus-connect-server-repo-latest.noarch.rpm'`

##### <a name="-globus--gcs_repo_baseurl"></a>`gcs_repo_baseurl`

Data type: `Variant[Stdlib::Httpsurl, Stdlib::Httpurl]`

Globus Connect Server repo baseurl

Default value: `"https://downloads.globus.org/globus-connect-server/stable/rpm/el/${facts['os']['release']['major']}/\$basearch/"`

##### <a name="-globus--gcs_repo_testing_baseurl"></a>`gcs_repo_testing_baseurl`

Data type: `Variant[Stdlib::Httpsurl, Stdlib::Httpurl]`

Globus testing repo baseurl

Default value: `"https://downloads.globus.org/globus-connect-server/testing/rpm/el/${facts['os']['release']['major']}/\$basearch/"`

##### <a name="-globus--enable_testing_repos"></a>`enable_testing_repos`

Data type: `Boolean`

Boolean that sets if testing repos should be added

Default value: `false`

##### <a name="-globus--extra_gridftp_settings"></a>`extra_gridftp_settings`

Data type: `Array`

Additional settings for GridFTP

Default value: `[]`

##### <a name="-globus--manage_service"></a>`manage_service`

Data type: `Boolean`

Boolean to set if globus-gridftp-server service is managed

Default value: `true`

##### <a name="-globus--run_setup_commands"></a>`run_setup_commands`

Data type: `Boolean`

Boolean to set if the commands to setup Globus are run (v4 and v5)

Default value: `true`

##### <a name="-globus--manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

Boolean to set if firewall rules are managed by this module

Default value: `true`

##### <a name="-globus--manage_epel"></a>`manage_epel`

Data type: `Boolean`

Boolean to set if EPEL is managed by this repo

Default value: `true`

##### <a name="-globus--manage_user"></a>`manage_user`

Data type: `Boolean`

Boolean to set if the gcsweb user and group are managed by this module

Default value: `true`

##### <a name="-globus--group_gid"></a>`group_gid`

Data type: `Optional[Integer]`

The gcsweb group GID

Default value: `undef`

##### <a name="-globus--user_uid"></a>`user_uid`

Data type: `Optional[Integer]`

The gcsweb user UID

Default value: `undef`

##### <a name="-globus--package_name"></a>`package_name`

Data type: `String`

Globus package name

Default value: `'globus-connect-server54'`

##### <a name="-globus--display_name"></a>`display_name`

Data type: `String[1]`

Display name to use when running 'globus-connect-server endpoint setup'

##### <a name="-globus--project_id"></a>`project_id`

Data type: `Optional[String[1]]`

--project-id use when running 'globus-connect-server endpoint setup'

Default value: `undef`

##### <a name="-globus--project_admin"></a>`project_admin`

Data type: `Optional[String[1]]`

--project-admin use when running 'globus-connect-server endpoint setup'

Default value: `undef`

##### <a name="-globus--owner"></a>`owner`

Data type: `String[1]`

--owner use when running 'globus-connect-server endpoint setup'

##### <a name="-globus--organization"></a>`organization`

Data type: `String[1]`

--organization use when running 'globus-connect-server endpoint setup'

##### <a name="-globus--deployment_key"></a>`deployment_key`

Data type: `Stdlib::Absolutepath`

--deployment-key use when running 'globus-connect-server endpoint setup'
The parent directory of this path must be writable by gcsweb user

Default value: `'/var/lib/globus-connect-server/gcs-manager/deployment-key.json'`

##### <a name="-globus--keywords"></a>`keywords`

Data type: `Optional[Array]`

--keywords use when running 'globus-connect-server endpoint setup'

Default value: `undef`

##### <a name="-globus--department"></a>`department`

Data type: `Optional[String]`

--department use when running 'globus-connect-server endpoint setup'

Default value: `undef`

##### <a name="-globus--contact_email"></a>`contact_email`

Data type: `Optional[String]`

--contact-email use when running 'globus-connect-server endpoint setup'

Default value: `undef`

##### <a name="-globus--contact_info"></a>`contact_info`

Data type: `Optional[String]`

--contact-info use when running 'globus-connect-server endpoint setup'

Default value: `undef`

##### <a name="-globus--info_link"></a>`info_link`

Data type: `Optional[String]`

--info-link use when running 'globus-connect-server endpoint setup'

Default value: `undef`

##### <a name="-globus--description"></a>`description`

Data type: `Optional[String]`

--description use when running 'globus-connect-server endpoint setup'

Default value: `undef`

##### <a name="-globus--public"></a>`public`

Data type: `Boolean`

When false pass --private flag to 'globus-connect-server endpoint setup'

Default value: `true`

##### <a name="-globus--incoming_port_range"></a>`incoming_port_range`

Data type: `Array[Stdlib::Port, 2, 2]`

--incoming-port-range use when running 'globus-connect-server node setup'

Default value: `[50000, 51000]`

##### <a name="-globus--outgoing_port_range"></a>`outgoing_port_range`

Data type: `Optional[Array[Stdlib::Port, 2, 2]]`

--outgoing-port-range use when running 'globus-connect-server node setup'

Default value: `undef`

##### <a name="-globus--ip_address"></a>`ip_address`

Data type: `Optional[Stdlib::IP::Address]`

--ip-address use when running 'globus-connect-server node setup'

Default value: `undef`

##### <a name="-globus--export_node"></a>`export_node`

Data type: `Optional[Stdlib::Absolutepath]`

--export-node use when running 'globus-connect-server node setup'

Default value: `undef`

##### <a name="-globus--import_node"></a>`import_node`

Data type: `Optional[Stdlib::Absolutepath]`

--import-node use when running 'globus-connect-server node setup'

Default value: `undef`

### <a name="globus--cli"></a>`globus::cli`

Manage Globus CLI

#### Examples

##### 

```puppet
include ::globus::cli
```

#### Parameters

The following parameters are available in the `globus::cli` class:

* [`ensure`](#-globus--cli--ensure)
* [`install_path`](#-globus--cli--install_path)
* [`manage_python`](#-globus--cli--manage_python)

##### <a name="-globus--cli--ensure"></a>`ensure`

Data type: `String[1]`

The ensure parameter for PIP installed CLI

Default value: `'present'`

##### <a name="-globus--cli--install_path"></a>`install_path`

Data type: `Stdlib::Absolutepath`

Path to install Globus CLI virtualenv

Default value: `'/opt/globus-cli'`

##### <a name="-globus--cli--manage_python"></a>`manage_python`

Data type: `Boolean`

Boolean to set if Python is managed by this class

Default value: `true`

### <a name="globus--sdk"></a>`globus::sdk`

Manage Globus SDK

#### Examples

##### 

```puppet
include globus::sdk
```

#### Parameters

The following parameters are available in the `globus::sdk` class:

* [`ensure`](#-globus--sdk--ensure)
* [`install_path`](#-globus--sdk--install_path)
* [`manage_python`](#-globus--sdk--manage_python)

##### <a name="-globus--sdk--ensure"></a>`ensure`

Data type: `String[1]`

The ensure parameter for PIP installed SDK

Default value: `'present'`

##### <a name="-globus--sdk--install_path"></a>`install_path`

Data type: `Stdlib::Absolutepath`

Path to install Globus CLI virtualenv

Default value: `'/opt/globus-sdk'`

##### <a name="-globus--sdk--manage_python"></a>`manage_python`

Data type: `Boolean`

Boolean to set if Python is managed by this class

Default value: `true`

### <a name="globus--timer"></a>`globus::timer`

Manage Globus Timer

#### Examples

##### 

```puppet
include ::globus::timer
```

#### Parameters

The following parameters are available in the `globus::timer` class:

* [`ensure`](#-globus--timer--ensure)
* [`install_path`](#-globus--timer--install_path)
* [`manage_python`](#-globus--timer--manage_python)

##### <a name="-globus--timer--ensure"></a>`ensure`

Data type: `String[1]`

The ensure parameter for PIP installed globus-timer-cli

Default value: `'present'`

##### <a name="-globus--timer--install_path"></a>`install_path`

Data type: `Stdlib::Absolutepath`

Path to install Globus Timer CLI virtualenv

Default value: `'/opt/globus-timer'`

##### <a name="-globus--timer--manage_python"></a>`manage_python`

Data type: `Boolean`

Boolean to set if Python is managed by this class

Default value: `true`

## Functions

### <a name="globus--endpoint_setup_args"></a>`globus::endpoint_setup_args`

Type: Ruby 4.x API

The globus::endpoint_setup_args function.

#### `globus::endpoint_setup_args(Hash $values)`

The globus::endpoint_setup_args function.

Returns: `Any`

##### `values`

Data type: `Hash`



### <a name="globus--node_setup_args"></a>`globus::node_setup_args`

Type: Ruby 4.x API

The globus::node_setup_args function.

#### `globus::node_setup_args(Hash $values)`

The globus::node_setup_args function.

Returns: `Any`

##### `values`

Data type: `Hash`



